@@ -2,6 +2,7 @@
 *   Copyright (C) 2008 Nicola Gigante <nicola.gigante@gmail.com>
 *   Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
 *   Copyright (C) 2009-2010 Dario Freddi <drf@kde.org>
+*   Copyright (C) 2020 David Edmundson <davidedmundson@kde.org>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +34,7 @@
 
 #include <PolkitQt1/Authority>
 #include <PolkitQt1/Subject>
+#include <polkitqt1-version.h>
 
 #include "kauthdebug.h"
 
@@ -61,7 +63,6 @@ PolkitQt1::Authority::Result PolkitResultEventLoop::result() const
 
 Polkit1Backend::Polkit1Backend()
     : AuthBackend()
-    , m_flyingActions(false)
 {
     setCapabilities(AuthorizeFromHelperCapability | CheckActionExistenceCapability | PreAuthActionCapability);
 
@@ -70,12 +71,6 @@ Polkit1Backend::Polkit1Backend()
             this, SLOT(checkForResultChanged()));
     connect(PolkitQt1::Authority::instance(), SIGNAL(consoleKitDBChanged()),
             this, SLOT(checkForResultChanged()));
-    connect(PolkitQt1::Authority::instance(), SIGNAL(enumerateActionsFinished(PolkitQt1::ActionDescription::List)),
-            this, SLOT(updateCachedActions(PolkitQt1::ActionDescription::List)));
-
-    // Cache existing action IDs as soon as possible
-    m_flyingActions = true;
-    PolkitQt1::Authority::instance()->enumerateActions();
 }
 
 Polkit1Backend::~Polkit1Backend()
@@ -94,7 +89,7 @@ void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
     // Are we running our KDE auth agent?
     if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.polkit-kde-authentication-agent-1"))) {
         // Check if we actually are entitled to use GUI capabilities
-        if (qApp == 0 || !qobject_cast<QApplication *>(qApp)) {
+        if (qApp == nullptr || !qobject_cast<QApplication *>(qApp)) {
             qCDebug(KAUTH) << "Not streaming parent as we are on a TTY application";
         }
 
@@ -120,15 +115,6 @@ void Polkit1Backend::preAuthAction(const QString &action, QWidget *parent)
     }
 }
 
-void Polkit1Backend::updateCachedActions(const PolkitQt1::ActionDescription::List &actions)
-{
-    m_knownActions.clear();
-    Q_FOREACH (const PolkitQt1::ActionDescription &action, actions) {
-        m_knownActions << action.actionId();
-    }
-    m_flyingActions = false;
-}
-
 Action::AuthStatus Polkit1Backend::authorizeAction(const QString &action)
 {
     Q_UNUSED(action)
@@ -151,6 +137,7 @@ Action::AuthStatus Polkit1Backend::actionStatus(const QString &action)
     if (authority->hasError()) {
         qCDebug(KAUTH) << "Encountered error while checking action status, error code:" << authority->lastError() << authority->errorDetails();
         authority->clearError();
+        return Action::InvalidStatus;
     }
 
     switch (r) {
@@ -174,15 +161,22 @@ AuthBackend::ExtraCallerIDVerificationMethod Polkit1Backend::extraCallerIDVerifi
     return VerifyAgainstDBusServiceName;
 }
 
-bool Polkit1Backend::isCallerAuthorized(const QString &action, QByteArray callerID)
+bool Polkit1Backend::isCallerAuthorized(const QString &action, const QByteArray &callerID, const QVariantMap &details)
 {
     PolkitQt1::SystemBusNameSubject subject(QString::fromUtf8(callerID));
     PolkitQt1::Authority *authority = PolkitQt1::Authority::instance();
-
+    QMap<QString, QString> polkit1Details;
+    for (auto it = details.cbegin(); it != details.cend(); ++it) {
+        polkit1Details.insert(it.key(), it.value().toString());
+    }
     PolkitResultEventLoop e;
     connect(authority, SIGNAL(checkAuthorizationFinished(PolkitQt1::Authority::Result)),
             &e, SLOT(requestQuit(PolkitQt1::Authority::Result)));
+#if POLKITQT1_IS_VERSION(0, 113, 0)
+    authority->checkAuthorizationWithDetails(action, subject, PolkitQt1::Authority::AllowUserInteraction, polkit1Details);
+#else
     authority->checkAuthorization(action, subject, PolkitQt1::Authority::AllowUserInteraction);
+#endif
     e.exec();
 
     if (authority->hasError()) {
@@ -196,47 +190,39 @@ bool Polkit1Backend::isCallerAuthorized(const QString &action, QByteArray caller
     default:
         return false;
     }
-
-    return false;
 }
 
 void Polkit1Backend::checkForResultChanged()
 {
-    Q_FOREACH (const QString &action, m_cachedResults.keys()) {
-        if (m_cachedResults[action] != actionStatus(action)) {
-            m_cachedResults[action] = actionStatus(action);
-            emit actionStatusChanged(action, m_cachedResults[action]);
+    for (auto it = m_cachedResults.begin(); it != m_cachedResults.end(); ++it) {
+        const QString action = it.key();
+        if (it.value() != actionStatus(action)) {
+            *it = actionStatus(action);
+            emit actionStatusChanged(action, *it);
         }
     }
-
-    // Force updating known actions
-    PolkitQt1::Authority::instance()->enumerateActions();
-    m_flyingActions = true;
 }
 
 bool Polkit1Backend::actionExists(const QString &action)
 {
-    auto authority = PolkitQt1::Authority::instance();
-    if (m_flyingActions && authority->hasError()) {
-            // This can happen if enumerateActions call failed
-            qWarning() << "Encountered error while enumerating actions, error code:" << authority->lastError() << authority->errorDetails();
-            authority->clearError();
-            m_flyingActions = false;
-    }
+    return m_cachedResults.value(action) != Action::InvalidStatus;
+}
 
-    // Any flying actions?
-    if (m_flyingActions) {
-        int tries = 0;
-        while (m_flyingActions && tries < 10) {
-            // Wait max 2 seconds
-            QEventLoop e;
-            QTimer::singleShot(200, &e, SLOT(quit()));
-            e.exec();
-            ++tries;
+QVariantMap Polkit1Backend::backendDetails(const DetailsMap &details)
+{
+    QVariantMap backendDetails;
+    for (auto it = details.cbegin(); it != details.cend(); ++it) {
+        switch (it.key()) {
+            case Action::AuthDetail::DetailMessage:
+                backendDetails.insert(QStringLiteral("polkit.message"), it.value());
+                break;
+            case Action::AuthDetail::DetailOther:
+            default:
+                backendDetails.insert(QStringLiteral("other_details"), it.value());
+                break;
         }
     }
-
-    return m_knownActions.contains(action);
+    return backendDetails;
 }
 
 } // namespace Auth
