@@ -50,24 +50,22 @@ public:
     Action::AuthStatus actionStatus(const QString &) override;
     QByteArray callerID() const override;
     ExtraCallerIDVerificationMethod extraCallerIDVerificationMethod() const override;
-    bool isCallerAuthorized(const QString &action, QByteArray callerID) override;
+    virtual bool isCallerAuthorized(const QString &action, const QByteArray &callerID, const QVariantMap &details) override;
     bool actionExists(const QString &action) override;
+    QVariantMap backendDetails(const DetailsMap &details) override;
 
 private Q_SLOTS:
     void checkForResultChanged();
-    void updateCachedActions(const PolkitQt1::ActionDescription::List &actions);
 
 private:
     QHash<QString, Action::AuthStatus> m_cachedResults;
-    QStringList m_knownActions;
-    bool m_flyingActions;
 };
 
 class PolkitResultEventLoop : public QEventLoop
 {
     Q_OBJECT
 public:
-    PolkitResultEventLoop(QObject *parent = 0);
+    PolkitResultEventLoop(QObject *parent = nullptr);
     virtual ~PolkitResultEventLoop();
 
     PolkitQt1::Authority::Result result() const;
