@@ -83,7 +83,7 @@ QVariantMap ExecuteJob::data() const
 void ExecuteJob::start()
 {
     if (!d->action.isValid()) {
-        qCWarning(KAUTH) << "Tried to start an invalid action";
+        qCWarning(KAUTH) << "Tried to start an invalid action: " << d->action.name();
         ActionReply reply(ActionReply::InvalidActionError);
         reply.setErrorDescription(tr("Tried to start an invalid action"));
         d->actionPerformedSlot(d->action.name(), reply);
@@ -92,10 +92,10 @@ void ExecuteJob::start()
 
     switch (d->mode) {
     case Action::ExecuteMode:
-        QTimer::singleShot(0, this, SLOT(doExecuteAction()));
+        QTimer::singleShot(0, this, [this]() {d->doExecuteAction();});
         break;
     case Action::AuthorizeOnlyMode:
-        QTimer::singleShot(0, this, SLOT(doAuthorizeAction()));
+        QTimer::singleShot(0, this, [this]() {d->doAuthorizeAction();});
         break;
     default: {
         ActionReply reply(ActionReply::InvalidActionError);
@@ -125,7 +125,7 @@ void ExecuteJob::Private::doExecuteAction()
 
         if (s == Action::AuthorizedStatus) {
             if (action.hasHelper()) {
-                BackendsManager::helperProxy()->executeAction(action.name(), action.helperId(), action.arguments(), action.timeout());
+                BackendsManager::helperProxy()->executeAction(action.name(), action.helperId(), action.detailsV2(), action.arguments(), action.timeout());
             } else {
                 // Done
                 actionPerformedSlot(action.name(), ActionReply::SuccessReply());
@@ -160,7 +160,7 @@ void ExecuteJob::Private::doExecuteAction()
             actionPerformedSlot(action.name(), r);
             return;
         }
-        BackendsManager::helperProxy()->executeAction(action.name(), action.helperId(), action.arguments(), action.timeout());
+        BackendsManager::helperProxy()->executeAction(action.name(), action.helperId(), action.detailsV2(), action.arguments(), action.timeout());
     } else {
         // There's something totally wrong here
         ActionReply r(ActionReply::BackendError);
